Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LogMiddleware ¶
LogMiddleware is a wrapper for the http handler. It gets passed the handler and returns the same handler with added logging and timing functionalities.
Types ¶
type APIServer ¶
type APIServer struct {
// contains filtered or unexported fields
}
APIServer is a structure that defines the API Server. This is defined in order for it to be easily created with a structure that defines the API Routes
func NewAPIServer ¶
NewAPIServer creates and runs a new API Server
func (APIServer) BuildAndServeAPI ¶
func (s APIServer) BuildAndServeAPI()
BuildAndServeAPI is the function used to serve the API endpoints
Click to show internal directories.
Click to hide internal directories.